@@ -33,7 +33,7 @@ structure(list(TICK_PRICE = "1", TICK_SIZE = "2",
     CURRENT_TIME = "49", REAL_TIME_BARS = "50", FUNDAMENTAL_DATA = "51",
     CONTRACT_DATA_END = "52", OPEN_ORDER_END = "53",
     ACCT_DOWNLOAD_END = "54", EXECUTION_DATA_END = "55",
-    DELTA_NEUTRAL_VALIDATION = "56"), .Names = c("TICK_PRICE", 
+    DELTA_NEUTRAL_VALIDATION = "56", TICK_SNAPSHOT_END = "57"), .Names = c("TICK_PRICE", 
 "TICK_SIZE", "ORDER_STATUS", "ERR_MSG", "OPEN_ORDER", "ACCT_VALUE", 
 "PORTFOLIO_VALUE", "ACCT_UPDATE_TIME", "NEXT_VALID_ID", "CONTRACT_DATA", 
 "EXECUTION_DATA", "MARKET_DEPTH", "MARKET_DEPTH_L2", "NEWS_BULLETINS", 
@@ -41,7 +41,7 @@ structure(list(TICK_PRICE = "1", TICK_SIZE = "2",
 "SCANNER_PARAMETERS", "SCANNER_DATA", "TICK_OPTION_COMPUTATION", 
 "TICK_GENERIC", "TICK_STRING", "TICK_EFP", "CURRENT_TIME", "REAL_TIME_BARS",
 "FUNDAMENTAL_DATA","CONTRACT_DATA_END", "OPEN_ORDER_END", "ACCT_DOWNLOAD_END",
-"EXECUTION_DATA_END","DELTA_NEUTRAL_VALIDATION"
+"EXECUTION_DATA_END","DELTA_NEUTRAL_VALIDATION","TICK_SNAPSHOT_END"
 ))
 
 `.twsERR` <-
